function [model_params,savename] = ...
              init(house,gridmix,alg,tariff,P_PV,E_B)
%[model_params,savename] = ...
%                init(house,gridmix,alg,tariff,P_PV,E_B)
%     initialises model parameters: house = 4 (NOT PROVIDED due to data
%     privacy), gridmix = MGR(t) data, alg = algorithm (not used), tariff =
%     electricity bill tariff (not used), P_PV = PV capacity (kW), E_B =
%     battery capacity (kWh). Saves all parameters calculated from these
%     into the cell array model_params
  
  savename = [num2str(house),'_',num2str(alg),...
          num2str(tariff),'_',num2str(round(P_PV*1000)),'_',...
          num2str(round(E_B*1000))];  

      load('DickonPVdata.mat','Pgen')
      dtPV = 5/60/60; % hours
      Pgen0 = Pgen; % kW/kW
      % feed-in tariff plus 50 % deemed export tariff (GBP/kWh)  
      FiT = 0.0378 + 0.5*0.0503; 
  
%% house
  switch house
      case 0
        load('HillViewData.mat','Pload')
        dtload = 15/60; % hours
        Pload0 = Pload; % kW
      case 1
        load('UKload2cleaned2.mat')
        dtload = 5/60; % hours
        Pload0 = loadP1(1:8760*12); % kW
      case 2
        load('UKload1cleaned2.mat')
        dtload = 5/60; % hours
        Pload0 = loadP1(1:8760*12); % kW
      case 3
        load('UKload4cleaned2.mat')
        dtload = 5/60; % hours
        Pload0 = loadP1(1:8760*12); % kW
      case 4
        load('UKload3cleaned2.mat')
        dtload = 5/60; % hours
        Pload0 = loadP1(1:8760*12); % kW
      case 5
        load('UKload6cleaned2.mat')
        dtload = 5/60; % hours
        Pload0 = loadP1(1:8760*12); % kW
      case 6
        load('UKload5cleaned2.mat')
        dtload = 5/60; % hours
        Pload0 = loadP1(1:8760*12); % kW
  end
  
  dt = max([dtPV,dtload]); % timestep (h) is coarsest of PV/load timestep
  Ndt = round(8760/dt);    % total number of timesteps in 1y (8760 h)
  Pgen1 = zeros(1,Ndt);    % Now to regularise PV and load to the newly-
  Pload1 = zeros(1,Ndt);   %   defined timestep
  for nt = 1:round(Ndt)
    Pgen1(nt) = mean(Pgen0(round((nt-1)*dt/dtPV+1):round(nt*dt/dtPV)));
    Pload1(nt) = mean(Pload0(round((nt-1)*dt/dtload+1):round(nt*dt/dtload)));
  end
  Pgen0 = (Pgen1);
  Pload0 = Pload1;
  
  t1 = datetime(2017,1,1,0,dt*60,0);
  t2 = datetime(2018,1,1,0,0,0);
  t = t1:hours(dt):t2;
  t0 = datetime(2017,1,1,0,30,0):hours(0.5):t2;
    
%% gridmix
  c_g_cc = 0.937*gridmix{1} + 0.394*gridmix{2} + 0.12*gridmix{3} +...
               0.053*gridmix{5} + 0.474*gridmix{6};
  c_g_cc = interp1([t0(1)-hours(0.5),t0],[c_g_cc(1),c_g_cc],t);
  g_params = {c_g_cc};
  
% alg = 0 means greedy algorithm

%% tariff
% cost of electricity
  c_g_GBP = zeros(size(t));
  switch tariff
    case 0 % flat tariff
      c_g_GBP = repmat(0.124,size(c_g_GBP));
      c_g_stand = 0.2; % standing charge
    case 1 % economy 7
      c_g_stand = 0.1865; % standing charge
      nightmask = [ones(1,8),zeros(1,18)];
      x = -0.5:24.5;
      xq = 0:dt:24;
      nightmask = round(interp1(x,nightmask,xq));
      nightmask = repmat(nightmask(2:end),1,365);
      c_g_GBP(logical(1-nightmask)) = 0.1326; % day rate
      c_g_GBP(logical(nightmask)) = 0.0726; % night rate
    case 2 % WREN sunshine tariff
      c_g_stand = 0; % standing charge
      c_g_GBP = repmat(0.134,size(c_g_GBP)); % standard rate
      xq = 0:dt:365*24;
      x = -0.5:365*24+0.5;
      summermask = zeros(1,24*365);
      summermask(24*90+1:24*273) = 1;
      summermask = round(interp1(x,[0,summermask,0],xq));
      summermask = summermask(2:end);
      x = -0.5:24.5;
      xq = 0:dt:24;
      nightmask = [ones(1,11),zeros(1,6),ones(1,9)];
      nightmask = interp1(x,nightmask,xq);
      nightmask = round(repmat(nightmask(2:end),1,365));
      c_g_GBP(logical(summermask.*(1-nightmask))) = 0.05; % summer day rate
      c_g_GBP(logical(summermask.*nightmask)) = 0.18; % summer night rate
    case 3 % Green Energy tide
      c_g_stand = 0.2602; % standing charge
      c_g_GBP = repmat(0.1402,size(c_g_GBP)); % standard rate
      xq = 0:dt:365*24;
      x = -12:24:365*24+12;
      weekmask = repmat([1,1,1,1,1,0,0],1,ceil(365/7));
      weekmask = [0,0,weekmask];
      weekmask = round(interp1(x,weekmask(1:367),xq));
      weekmask = weekmask(2:end);
      x = -0.5:24.5;
      xq = 0:dt:24;
      lowmask = [ones(1,8),zeros(1,18)];
      lowmask = round(interp1(x,lowmask,xq));
      lowmask = repmat(lowmask(2:end),1,365);
      highmask = [zeros(1,17),ones(1,4),zeros(1,5)];
      highmask = round(interp1(x,highmask,xq));
      highmask = repmat(highmask(2:end),1,365);
      c_g_GBP(logical(weekmask.*lowmask)) = 0.0641; % weeknight rate
      c_g_GBP(logical(weekmask.*highmask)) = 0.2999; % week evening rate
      c_g_GBP(logical((1-weekmask).*lowmask)) = 0.0641; % wkend night rate
  end
% inflation rate (rise of elec unit price)
  r_infl = 0.058;
  tariff_params = {c_g_GBP,c_g_stand,r_infl};
%% battery parameters
  eta_dc = 0.97; % DC-DC converter efficiency (1-way)
  eta_inv = 0.97; % inverter efficiency (1-way)
  eta_B = 0.985; % charge efficiency
  E_B_low = 0.0357;
  E_B_high = 1.00;
  P_B = 0.5; % max charge/discharge C-rate
  selfdis = 0.001; % C-rate standby consumption
  
  B_params = {eta_dc,eta_inv,eta_B,E_B_low,E_B_high,P_B,selfdis};

%%
% interest rate (NPV discounting of cash flow)
  r_int = 0.04;
% environmental impacts discount rate
  r_int_env = 0.015;

  other_params = {r_int,r_int_env,FiT};
%%
  base_params={P_PV,E_B,dt,t,alg,house,gridmix,tariff};
  model_params = {Pgen0,Pload0,base_params,B_params,...
                              g_params,tariff_params,other_params};
end

